from io import open
import setuptools

long_description = ""

version = '1.5.2'


setuptools.setup(
    name = 'm_package',
    version = version,

    author = 'Misha',
    long_description = long_description,

    url = 'https://github.com/MihailKur',

    packages = ['m_package']
)